# Reference

<meta http-equiv="Refresh" content="0; url=./lamindb.html" />

```{toctree}
:maxdepth: 1
:caption: Core API
:hidden:

lamindb
```

```{toctree}
:maxdepth: 1
:caption: Plug-ins
:hidden:

lnschema-bionty
```

```{toctree}
:maxdepth: 1
:caption: Utilities
:hidden:

readfcs
bionty
nbproject
lamin-utils
```
